@@ -48,10 +48,8 @@ class App:
         self.window.props.hide_titlebar_when_maximized = True
         self.window.set_icon(self.theme['app-logo'])
         app.add_window(self.window)
-        self.window.connect('check-resize',
-                self.on_main_window_resized)
-        self.window.connect('delete-event',
-                self.on_main_window_deleted)
+        self.window.connect('check-resize', self.on_main_window_resized)
+        self.window.connect('delete-event', self.on_main_window_deleted)
 
         self.accel_group = Gtk.AccelGroup()
         self.window.add_accel_group(self.accel_group)
@@ -65,15 +63,10 @@ class App:
         self.notebook = Gtk.Notebook()
         self.notebook.props.tab_pos = Gtk.PositionType.BOTTOM
         self.notebook.get_style_context().add_class('main_tab')
-        # Add 2 pix to left-margin to solve Fullscreen problem.
-        #self.notebook.props.margin_left = 2
         box.pack_start(self.notebook, True, True, 0)
 
-        # signal should be connected after all pages in notebook
-        # all added.
         self.init_notebook()
-        self.notebook.connect('switch-page',
-                self.on_notebook_switch_page)
+        self.notebook.connect('switch-page', self.on_notebook_switch_page)
         self.init_status_icon()
 
         # load styles
@@ -180,11 +173,18 @@ class App:
                 'transition-property: background-image;',
                 'transition-duration: 1s;',
                 '}',
+            'GtkScale {',
+                #'border-style: none;',
+                'outline-color: transparent;',
+                'outline-offset: 0;',
+                'outline-style: none;',
+                'outline-width: 0;',
+                '}',
             'GtkTextView.lrc_tv {',
                 'font-size: {0}{1};'.format(font_size, px),
                 'color: {0};'.format(self.conf['lrc-text-color']),
-                'border-radius: 0 25px 0 50px;',
-                'border-width: 5px;',
+                'border-radius: 0 25{0} 0 50{0};'.format(px),
+                'border-width: 5{0};'.format(px),
                 'background-color: {0};'.format(
                     self.conf['lrc-back-color']),
                 '}',
@@ -201,8 +201,7 @@ class App:
         self.status_icon = Gtk.StatusIcon()
         self.status_icon.set_from_pixbuf(self.theme['app-logo'])
         # left click
-        self.status_icon.connect('activate',
-                self.on_status_icon_activate)
+        self.status_icon.connect('activate', self.on_status_icon_activate)
         # right click
         self.status_icon.connect('popup_menu', 
                 self.on_status_icon_popup_menu)
@@ -218,32 +217,27 @@ class App:
             event_time):
         menu = Gtk.Menu()
         show_item = Gtk.MenuItem(label=_('Show App') )
-        show_item.connect('activate',
-                self.on_status_icon_show_app_activate)
+        show_item.connect('activate', self.on_status_icon_show_app_activate)
         menu.append(show_item)
 
         pause_item = Gtk.MenuItem(label=_('Pause/Resume'))
-        pause_item.connect('activate',
-                self.on_status_icon_pause_activate)
+        pause_item.connect('activate', self.on_status_icon_pause_activate)
         menu.append(pause_item)
 
         next_item = Gtk.MenuItem(label=_('Next Song'))
-        next_item.connect('activate',
-                self.on_status_icon_next_activate)
+        next_item.connect('activate', self.on_status_icon_next_activate)
         menu.append(next_item)
 
         sep_item = Gtk.SeparatorMenuItem()
         menu.append(sep_item)
         
         quit_item = Gtk.MenuItem(label=_('Quit'))
-        quit_item.connect('activate', 
-                self.on_status_icon_quit_activate)
+        quit_item.connect('activate', self.on_status_icon_quit_activate)
         menu.append(quit_item)
 
         menu.show_all()
         menu.popup(None, None,
-                lambda a,b: Gtk.StatusIcon.position_menu(menu,
-                    status_icon),
+                lambda a,b: Gtk.StatusIcon.position_menu(menu, status_icon),
                 None, event_button, event_time)
 
     def on_status_icon_show_app_activate(self, menuitem):
