@@ -25,7 +25,7 @@ locale.textdomain('kwplayer')
 _ = gettext.gettext
 
 APPNAME = _('KW Player')
-VERSION = '3.2.2'
+VERSION = '3.2.3'
 HOMEPAGE = 'https://github.com/LiuLang/kwplayer'
 AUTHORS = ['LiuLang <gsushzhsosgsu@gmail.com>',]
 DESCRIPTION = _('A simple music player on Linux desktop.')
@@ -46,6 +46,8 @@ CACHE_DB = os.path.join(CACHE_DIR, 'cache.db')
 PLS_JSON = os.path.join(CACHE_DIR, 'pls.json')
 # store radio playlist.
 RADIO_JSON = os.path.join(CACHE_DIR, 'radio.json')
+# favorite artists list.
+FAV_ARTISTS_JSON = os.path.join(CACHE_DIR, 'fav_artists.json')
 
 THEME_DIR = os.path.join(PREF, 'kuwo', 'themes', 'default')
 
